package com.jose.businessclients;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;



public class BDAdaptor {
	//Variables de base de datos
	public static final String NOMBRE_CONTACTOS = "nombre";
	private static final String GRUPO_CONTACTOS = "grupo";
	private static final String EMPRESA_CONTACTOS = "empresa";
	private static final String PROVINCIA_CONTACTOS = "provincia";
	private static final String CIUDAD_CONTACTOS = "ciudad";
	private static final String CALLE_CONTACTOS = "calle";
	private static final String EMAIL_CONTACTOS = "email";
	private static final String WEB_CONTACTOS = "web";
	private static final String NOMBRE_GRUPOS = "nombre";
	private static final String NOMBRE_BASEDATOS = "BusinessContacts";
	private static final String TABLA_CONTACTOS = "contacts";
	private static final String TABLA_GRUPOS = "groups";
	private static final String TABLA_TELEFONOS = "telefonos";
	private static final int VERSION_BASEDATOS = 1;
	private static final String CREAR_TABLA_CONTACTOS = "create table contacts (nombre text primary key, grupo text, empresa text, provincia text, ciudad text, calle text, email text, web text);";
	private static final String CREAR_TABLA_GRUPOS = "create table groups (nombre text primary key);";
	private static final String CREAR_TABLA_TELEFONOS = "create table telefonos (numero text primary key, tipo text, nombre text);";
	private static final String CREAR_TABLA_CONFIGURACION = "create table configuracion (accion text primary key, pantalla text, firsttime text);";
	//Variables de clase
	private final Context context;
	private DBHelper dbh;
	private SQLiteDatabase db;

	public BDAdaptor(Context ctx) {
		this.context = ctx;
		dbh = new DBHelper(context);
	}

	private static class DBHelper extends SQLiteOpenHelper {
		DBHelper(Context context) {
			super(context, NOMBRE_BASEDATOS, null, VERSION_BASEDATOS);
		}

		@Override
		public void onCreate(SQLiteDatabase db) {
			try {
				db.execSQL(CREAR_TABLA_CONTACTOS);
				db.execSQL(CREAR_TABLA_GRUPOS);
				db.execSQL(CREAR_TABLA_TELEFONOS);
				db.execSQL(CREAR_TABLA_CONFIGURACION);
				db.execSQL("insert into configuracion (accion, pantalla, firsttime) values ('0','0','0');");
			} catch (SQLException e) {
				e.printStackTrace();
			}
		}

		@Override
		public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
			onCreate(db);
		}
	}

	//abrir base de datos
	public BDAdaptor abrir_escritura() throws SQLException {
		db = dbh.getWritableDatabase();
		return this;
	}

	//cerrar base de datos
	public void cerrar() {
		dbh.close();
	}
	
	//insertar grupo
	public long insertarGrupo(String grupo) {
		ContentValues valores = new ContentValues();
		valores.put(NOMBRE_GRUPOS, grupo);
		return db.insert(TABLA_GRUPOS, null, valores);
	}
	
	//actualizar grupo
	public void modificarGrupo(String antiguo, String nuevo) {
		db.execSQL("UPDATE groups SET nombre='"+nuevo+ "' WHERE nombre='" + antiguo+"'");
	}
	
	//eliminar grupo
	public void eliminarGrupo(String grupo) {
		db.execSQL("DELETE FROM groups WHERE nombre='" + grupo + "'");
		db.execSQL("UPDATE contacts SET grupo ='' WHERE grupo='"+grupo+"'");
	}
	
	//consultar accion
	public Cursor obtenerAccion() {
		return db.rawQuery("select accion from configuracion", null);
	}
	
	//consultar valor firsttime
	public Cursor obtenerConfiguracion() {
		return db.rawQuery("select firsttime from configuracion", null);
	}
	
	//consultar valor inicio
	public Cursor obtenerInicio() {
		return db.rawQuery("select pantalla from configuracion", null);
	}
	
	//actualizar accion
	public void modificarAccion(int anterior, int nuevo) {
		db.execSQL("update configuracion set accion = '"+nuevo+"' where accion ='"+anterior+"'");
	}
	
	//modificar valor de inicio
	public void modificarInicio(int anterior, int nuevo) {
		db.execSQL("update configuracion set pantalla = '"+nuevo+"' where pantalla ='"+anterior+"'");
	}
	
	//insertar nuevo contacto
	public long insertarContacto(String nombre, String grupo, String empresa, String provincia, String ciudad, String calle, String email, String web) {
		ContentValues valoresIniciales = new ContentValues();
		valoresIniciales.put(NOMBRE_CONTACTOS, nombre);
		valoresIniciales.put(GRUPO_CONTACTOS, grupo);
		valoresIniciales.put(EMPRESA_CONTACTOS, empresa);
		valoresIniciales.put(PROVINCIA_CONTACTOS, provincia);
		valoresIniciales.put(CIUDAD_CONTACTOS, ciudad);
		valoresIniciales.put(CALLE_CONTACTOS, calle);
		valoresIniciales.put(EMAIL_CONTACTOS, email);
		valoresIniciales.put(WEB_CONTACTOS, web);
		return db.insert(TABLA_CONTACTOS, null, valoresIniciales);
	}
	
	//insertar nuevo telefono
	public long insertarTelefono(String numero, String tipo, String nombre) {
		ContentValues valores = new ContentValues();
		valores.put("numero", numero);
		valores.put("tipo", tipo);
		valores.put("nombre", nombre);
		return db.insert(TABLA_TELEFONOS, null, valores);
	}
	
	//eliminar contacto
	public boolean eliminarContacto(String contacto) {
		boolean delete = db.delete(TABLA_CONTACTOS, "nombre = ?", new String[] {contacto}) > 0;
		if(delete == true) {
			delete = db.delete(TABLA_TELEFONOS, "nombre = ?", new String[] {contacto}) > 0; 
		}
		return delete;
	}

	//obtener listado de contactos
	public Cursor obtenerTodosLosContactos() {
		return db.rawQuery("select nombre,grupo,empresa,provincia,ciudad,calle,email,web from contacts order by nombre", null);
	}
	
	//obtener listado de grupos
	public Cursor obtenerGrupos(){
		return db.rawQuery("SELECT nombre FROM groups;", null);
	}
	
	//consultar datos contacto
	public Cursor obtenerContacto(String contacto) throws SQLException {
		Cursor miCursor = db.rawQuery("select nombre,grupo,empresa,provincia,ciudad,calle,email,web from contacts where nombre = ?", new String[] {contacto});
		return miCursor;
	}
	
	//consultar telefono
	public Cursor obtenerTelefono(String contacto) throws SQLException {
		Cursor miCursor = db.rawQuery("select nombre, numero, tipo from telefonos where nombre = '" + contacto + "'", null);
		return miCursor;
	}
	
	//modificar datos de contacto
	public boolean actualizarContacto(String name, String new_name, String grupo, String empresa, String provincia, String ciudad, String calle, String email, String web) {
		ContentValues valores = new ContentValues();
		valores.put(NOMBRE_CONTACTOS, new_name);
		valores.put(GRUPO_CONTACTOS, grupo);
		valores.put(EMPRESA_CONTACTOS, empresa);
		valores.put(PROVINCIA_CONTACTOS, provincia);
		valores.put(CIUDAD_CONTACTOS, ciudad);
		valores.put(CALLE_CONTACTOS, calle);
		valores.put(EMAIL_CONTACTOS, email);
		valores.put(WEB_CONTACTOS, web);
		return db.update(TABLA_CONTACTOS, valores, "nombre = ?", new String[] {name}) > 0;
	}
	
	//modificar telefono
	public boolean actualizarTelefono(String nombre, String new_name, String numero, String tipo) {
		ContentValues valores = new ContentValues();
		valores.put("numero", numero);
		valores.put("tipo", tipo);
		valores.put("nombre", new_name);
		return db.update(TABLA_TELEFONOS, valores, "nombre = ?", new String[] {nombre}) > 0;
	}
}
